/*
 * ReDirectorTest.java
 * 
 * Created 16.12.2005.
 * 
 * Copyright (c) 2005 Johann Burkard (<mailto:jb@eaio.com>)
 * <http://eaio.com>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 */
package com.eaio.j2ee.www.redirector;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.eaio.j2ee.MockHttpServletRequest;
import com.eaio.j2ee.MockHttpServletResponse;
import com.eaio.j2ee.MockServletConfig;
import com.eaio.util.junit.AbstractTestCase;

/**
 * Test case for the {@link com.eaio.j2ee.www.redirector.ReDirector} class.
 *
 * @author <a href="mailto:jb@eaio.com">Johann Burkard</a>
 * @version $Id$
 */
public class ReDirectorTest extends AbstractTestCase {

    public static void main(String[] args) {
        junit.awtui.TestRunner.run(ReDirectorTest.class);
    }

    protected ReDirector instance;

    /*
     * @see AbstractTestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        instance = new ReDirector();
        instance.init(new MockServletConfig() {

            /**
             * @see com.eaio.j2ee.MockServletConfig#getInitParameter(java.lang.String)
             */
            public String getInitParameter(String param) {
                if (ReDirector.PARAMETER_INTERVAL.equals(param)) {
                    return Long.toString(Math.random() < 0.5
                            ? (long) (Math.random() * Long.MAX_VALUE)
                            : (long) (Math.random() * Long.MAX_VALUE * -1));
                }
                else if (ReDirector.PARAMETER_LINKS.equals(param)) {
                    return "documentation/redirector/links.xml";
                }
                else if (ReDirector.PARAMETER_HOSTNAME.equals(param)) {
                    return "http://kalifornia.com";
                }
                return super.getInitParameter(param);
            }

        });
    }

    /*
     * @see TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        instance.destroy();
        super.tearDown();
    }

    /*
     * Test method for 'com.eaio.j2ee.www.redirector.ReDirector.doGet(HttpServletRequest, HttpServletResponse)'
     */
    public void testDoGetHttpServletRequestHttpServletResponse() {
        HttpServletRequest request;
        HttpServletResponse response;
        try {
            request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return "Google";
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html; charset=ISO-8859-1", type);
                }
                public void addHeader(String name, String value) {
                    assertTrue(value.indexOf("http://www.google.com") != -1);
                }
            };
            instance.doGet(request, response);
             request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return "blorb";
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html; charset=ISO-8859-1", type);
                }
                public void sendError(int arg0) throws IOException {
                    assertEquals(HttpServletResponse.SC_NOT_FOUND, arg0);
                }
            };
            instance.doGet(request, response);
            request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return null;
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html; charset=ISO-8859-1", type);
                }
                public void sendError(int arg0) throws IOException {
                    assertEquals(HttpServletResponse.SC_NOT_FOUND, arg0);
                }
            };
            instance.doGet(request, response);            
        }
        catch (Exception ex) {
            ex.printStackTrace();
            fail(ex.toString());
        }
    }

    /*
     * Test method for 'com.eaio.j2ee.www.redirector.ReDirector.doPost(HttpServletRequest, HttpServletResponse)'
     */
    public void testDoPostHttpServletRequestHttpServletResponse() {
        HttpServletRequest request;
        HttpServletResponse response;
        try {
            request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return "Google";
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html; charset=ISO-8859-1", type);
                }
                public void addHeader(String name, String value) {
                    assertTrue(value.indexOf("http://www.google.com") != -1);
                }
            };
            instance.doPost(request, response);
             request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return "blorb";
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html", type);
                }
                public void sendError(int arg0) throws IOException {
                    assertEquals(HttpServletResponse.SC_NOT_FOUND, arg0);
                }
            };
            instance.doPost(request, response);
            request = new MockHttpServletRequest() {
                public String getParameter(String arg0) {
                    return null;
                }
            };
            response = new MockHttpServletResponse() {
                public void setContentType(String type) {
                    assertEquals("text/html", type);
                }
                public void sendError(int arg0) throws IOException {
                    assertEquals(HttpServletResponse.SC_NOT_FOUND, arg0);
                }
            };
            instance.doPost(request, response);            
        }
        catch (Exception ex) {
            ex.printStackTrace();
            fail(ex.toString());
        }
    }

    /*
     * Test method for 'com.eaio.j2ee.www.redirector.ReDirector.getServletInfo()'
     */
    public void testGetServletInfo() {
        assertEquals("ReDirector - XML-based redirection servlet", instance.getServletInfo());
    }

}
